@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
 import json
 import yaml
+import multiprocessing as mp
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.mapping.statements import EvaluatedStatement, PartialStatement, StatementError
 from t2wml.utils.bindings import update_bindings, bindings
@@ -9,14 +10,13 @@ from t2wml.input_processing.region import YamlRegion
 from t2wml.input_processing.clean_yaml_parsing import get_cleaned_dataframe
 from t2wml.input_processing.annotation_parsing import Annotation
 from t2wml.input_processing.utils import string_is_valid
-from t2wml.spreadsheets.conversions import to_excel
 from t2wml.utils.debug_logging import basic_debug
 
 class StatementMapper(ABC):
     """an abstract class for creating statementmapper classes. refer to the api documentation for more details.
     """
     @abstractmethod
-    def get_cell_statement(self, sheet, wikifier, col, row, *args, **kwargs):
+    def get_cell_statement(self, col, row, do_init=False, sheet=None, wikifier=None, *args, **kwargs):
         raise NotImplementedError
     
     @abstractmethod
@@ -26,7 +26,7 @@ class StatementMapper(ABC):
     def do_init(self, sheet, wikifier):
         pass
 
-    @basic_debug
+    #@basic_debug
     def get_statements(self, sheet, wikifier, start_index=0, end_index=None, count=None):
         self.do_init(sheet, wikifier)
         statements = {}
@@ -39,11 +39,10 @@ class StatementMapper(ABC):
         i=0
         for col, row in self.iterator(start_index, end_index):
             errors=[]
+            cell = (col-1, row-1)
             if string_is_valid(str(bindings.excel_sheet[row-1, col-1])):
-                cell = to_excel(col-1, row-1)
                 try:
-                    statement, inner_errors = self.get_cell_statement(
-                        sheet, wikifier, col, row, do_init=False)
+                    statement, inner_errors = self.get_cell_statement(col, row, do_init=False)
                     if "value" in statement: #exclude empty statements
                         statements[cell] = statement
                     if inner_errors:
@@ -76,7 +75,7 @@ class YamlMapper(StatementMapper):
         update_bindings(item_table=wikifier.item_table, sheet=sheet)
         
 
-    def get_cell_statement(self, sheet, wikifier, col, row, do_init=True):
+    def get_cell_statement(self, col, row, do_init=False, sheet=None, wikifier=None):
         if do_init:
             self.do_init(sheet, wikifier)
         context = {"t_var_row": row, "t_var_col": col}
@@ -139,7 +138,7 @@ class PartialAnnotationMapper(AnnotationMapper):
         if not self.annotation.data_annotations:
             self.get_statements=self.empty_get_statements
 
-    def get_cell_statement(self, sheet, wikifier, col, row, do_init=True):
+    def get_cell_statement(self, col, row, do_init=False, sheet=None, wikifier=None):
         if do_init:
             self.do_init(sheet, wikifier)
         context = {"t_var_row": row, "t_var_col": col}
