@@ -18,7 +18,7 @@ class PandasLoader:
         self.is_excel = True if self.file_extension in [".xlsx", ".xls"] else False
         self.pd_args = dict(dtype=str, header=None, na_filter=False)
 
-    @basic_debug
+    #@basic_debug
     def load_sheet(self, sheet_name):
         """
         returns a single sheet's data frame
@@ -40,7 +40,7 @@ class PandasLoader:
         return Path(self.file_path).name
 
 
-    @basic_debug
+    #@basic_debug
     def load_file(self):
         """
         returns a dictionary of sheet_names and their data frames
@@ -60,7 +60,7 @@ class PandasLoader:
             return {sheet_name: data}
 
 
-    @basic_debug
+    #@basic_debug
     def get_sheet_names(self):
         if self.is_excel:
             xl = pd.ExcelFile(self.file_path)
