@@ -1,5 +1,7 @@
 # bindings represents information used by classes/functions available in the t2wml parser
-from t2wml.utils.debug_logging import basic_debug
+# This class is HIGHLY PROBLEMATIC for multi-user systems. It should be combined with T2WMLSettings, 
+# and some method of passing along both to the parser without using a global function needs to be implemented
+
 class BindingsClass:
     def __init__(self):
         self.item_table = None
@@ -8,12 +10,11 @@ class BindingsClass:
 
 bindings = BindingsClass()
 
-@basic_debug
+
 def update_bindings(sheet=None, item_table=None) -> None:
-    """
-    This function updates the bindings dictionary with the excel_file, item_table, and sparql endpoint
+    """updates the bindings dictionary with the excel_file and item table
     """
     if sheet:
         bindings.excel_sheet = sheet
     if item_table:
-        bindings.item_table = item_table
\ No newline at end of file
+        bindings.item_table = item_table
